@@ -1,19 +1,16 @@
 #' @title Nonparametric additive instrumental variable estimator
-#' @description NAIVE is the nonparametric additive instrumental variable estimator with the
-#' adaptive group Lasso. It is using group lasso and B-splines to obtain the valid instrument
-#' variables where BIC or EBIC are applied to choose the tuning parameters. Then we get the
-#' two-stage least squares (2SLS) estimator with selected IV.
-#' @param y Response variable, a matrix Nx1
-#' @param x The design matrix, without an intercept
-#' @param z The instrument variables matrix
+#' @description NAIVE is the nonparametric additive instrumental variable estimator with the adaptive group Lasso. It uses group lasso and B-splines to obtain the valid instrument variables where BIC are applied to choose the tuning parameters. Then we get the two-stage least squares (2SLS) estimator with selected IV.
+#' @param y Response variable, a matrix N x 1.
+#' @param x The design matrix, without an intercept.
+#' @param z The instrument variables matrix.
 #' @param max.degree The upper limit value of degree of B-splines when using BIC/AIC to choose the tuning parameters, default is BIC.
-#' @param intercept Estimate with intercept or not, default is "TRUE"
-#' @param criterion The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc", or "EBIC"; default is "BIC".
-#' @param df.method How should effective model parameters be calculated? One of: "active", which counts the number of nonzero coefficients; or "default", which uses the calculated df returned by grpreg. default is "default".
-#' @param penalty The penalty to be applied to the model. For group selection, one of grLasso, grMCP, or grSCAD. For bi-level selection, one of gel or cMCP. Default is " grLasso".
-#' @param endogenous.index Specify which variables in design matrix are endogenous variables, the  variable corresponds to the value 1 is endogenous variables,  the  variable corresponds to the value 0  is exogenous variable, the default is all endogenous variables
-#' @param IV.intercept Intercept of instrument variables, default is “FALSE”
-#' @param family Either "gaussian" or "binomial", depending on the response.default is " gaussian "
+#' @param intercept Estimate with intercept or not, default is "TRUE".
+#' @param criterion The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc","EBIC", default is "BIC".
+#' @param df.method How should effective model parameters be calculated? One of: "active", which counts the number of nonzero coefficients; or "default", which uses the calculated df returned by grpreg, default is "default".
+#' @param penalty The penalty to be applied to the model. For group selection, one of grLasso, grMCP, or grSCAD. For bi-level selection, one of gel or cMCP, default is " grLasso".
+#' @param endogenous.index Specify which variables in design matrix are endogenous variables, the  variable corresponds to the value 1 is endogenous variables, thevariable corresponds to the value 0 is exogenous variable, the default is all endogenous variables.
+#' @param IV.intercept Intercept of instrument variables, default is “FALSE”.
+#' @param family Either "gaussian" or "binomial", depending on the response.default is " gaussian ".
 #' @details Consider the following structural equation with endogenous regressors\eqn{Y_{i}= x_{u}^{T}\beta+ \epsilon_{i}}
 #'
 #'To solve the endogeneity problem, instrumental variables are employed to obtain a consistent estimator of the population regression coefficient \eqn{\beta}. In practice, many potential instruments, including their series terms, may be recruited to approximate the optimal instrument and improve the precision of IV estimators. On the other hand, if many irrelevant instruments are contained in the reduced form equation, the approximation of the optimal instrument is generally unsatisfactory and the IV estimator is less efficient. In some cases where the dimensionality of \eqn{z_{i}}is even higher than the sample size, the linear IV method fails. To address these issues, the model sparsity is usually assumed and the penalized approaches can be applied to improve the efficiency of IV estimators. In this paper we propose the first-stage parsimonious predictive models and estimate optimal instruments in IV models with potentially more instruments than the sample size n.
@@ -34,16 +31,16 @@
 #'
 #' @return An object of type \code{naivereg} which is a list with the following
 #' components:
-#' \item{coefficients}{a vector of coefficients}
-#' \item{ste}{the standard deviation of the coefficients}
-#' \item{n}{number of samples}
-#' \item{degree}{degree of B-splines}
-#' \item{criterion}{The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc", or "EBIC"; default is "BIC".}
-#' \item{ind}{the index of selected instrument variables}
-#' \item{ind.b}{the index of selected instrument variables after B-splines}
-#' \item{res}{the difference between the predicted y and the actual y}
+#' \item{coefficients}{A vector of coefficients.}
+#' \item{ste}{The standard deviation of the coefficients.}
+#' \item{n}{Number of samples.}
+#' \item{degree}{Degree of B-splines.}
+#' \item{criterion}{The criterion by which to select the regularization parameter. One of "AIC", "BIC", "GCV", "AICc","EBIC"; default is "BIC".}
+#' \item{ind}{The index of selected instrument variables.}
+#' \item{ind.b}{The index of selected instrument variables after B-splines.}
+#' \item{res}{The difference between the predicted y and the actual y.}
 #' @author Qingliang Fan, KongYu He, Wei Zhong
-#' @references Q. Fan and W. Zhong (2017), “Nonparametric Additive Instrumental Variable Estimator: A Group Shrinkage Estimation Perspective,” Journal of Business & Economic Statistics, doi: 10.1080/07350015.2016.1180991.
+#' @references Q. Fan and W. Zhong (2018), “Nonparametric Additive Instrumental Variable Estimator: A Group Shrinkage Estimation Perspective,” Journal of Business & Economic Statistics, doi: 10.1080/07350015.2016.1180991.
 #' @references Caner, M. and Fan, Q. (2015), Hybrid GEL Estimators: Instrument Selection with Adaptive Lasso, Journal of Econometrics, Volume 187, 256–274.
 #' @examples
 #'#naive regression
@@ -51,20 +48,21 @@
 #'data("naivedata")
 #'x=naivedata[,1]
 #'y=naivedata[,2]
-#'z=naivedata[,3:102]
+#'z=naivedata[,3:22]
 #'#estimate with intercept
 #'naive_intercept= naivereg(y,x,z)
-#'#estimate without intercept,criterion:EBIC
-#'naive_without_intercept = naivereg(y,x,z,intercept=FALSE,criterion='EBIC')
+#'#estimate without intercept,criterion:AIC
+#'naive_without_intercept = naivereg(y,x,z,intercept=FALSE,criterion='AIC')
 #' @importFrom splines bs
 #' @importFrom grpreg grpreg select
 #' @importFrom gmm gmm gel
 #' @importFrom stats AIC BIC logLik
 #' @importFrom ncvreg ncvreg cv.ncvreg
 #' @importFrom stats glm lm
+#' @importFrom stats model.matrix predict binomial
+#' @importFrom glmnet glmnet
 #' @export
 
-
 naivereg <- function(y,x,z,max.degree=10,intercept=TRUE,criterion=c("BIC","AIC","GCV","AICc","EBIC"),
                        df.method=c("default","active"),
                        penalty = c("grLasso", "grMCP", "grSCAD", "gel", "cMCP"),endogenous.index=c(),IV.intercept=FALSE,family=c("gaussian", "binomial", "poisson")) {
@@ -100,7 +98,7 @@ naivereg <- function(y,x,z,max.degree=10,intercept=TRUE,criterion=c("BIC","AIC",
   IV<-IVselect(z,x,criterion=criterion,df.method=df.method,penalty=penalty,IV.intercept=IV.intercept,family=family)
   naivelasso <- est.iv(y,x,IV$IVselect,intercept)
 
-  list(coefficients=naivelasso$coefficients,ste=naivelasso$ste,n=naivelasso$n,degree=naivelasso$degree,criterion=criterion,
+  list(coefficients=naivelasso$coefficients,ste=naivelasso$ste,n=naivelasso$n,degree=IV$degree,criterion=criterion,
        ind=IV$ind,ind.b=IV$ind.b,res=naivelasso$residuals)
 
 }
